package com.ruoyi.szxc.mapper;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcCarInfo;

/**
 * 车辆信息Mapper接口
 * 
 * @author hs
 * @date 2024-03-15
 */
public interface SzxcCarInfoMapper 
{
    /**
     * 查询车辆信息
     * 
     * @param id 车辆信息主键
     * @return 车辆信息
     */
    public SzxcCarInfo selectSzxcCarInfoById(Long id);

    /**
     * 查询车辆信息列表
     * 
     * @param szxcCarInfo 车辆信息
     * @return 车辆信息集合
     */
    public List<SzxcCarInfo> selectSzxcCarInfoList(SzxcCarInfo szxcCarInfo);

    /**
     * 新增车辆信息
     * 
     * @param szxcCarInfo 车辆信息
     * @return 结果
     */
    public int insertSzxcCarInfo(SzxcCarInfo szxcCarInfo);

    /**
     * 修改车辆信息
     * 
     * @param szxcCarInfo 车辆信息
     * @return 结果
     */
    public int updateSzxcCarInfo(SzxcCarInfo szxcCarInfo);

    /**
     * 删除车辆信息
     * 
     * @param id 车辆信息主键
     * @return 结果
     */
    public int deleteSzxcCarInfoById(Long id);

    /**
     * 批量删除车辆信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSzxcCarInfoByIds(Long[] ids);
}
